@@ -17,6 +17,7 @@ from autotrader.lib.read_yaml import read_yaml
 class AutoTraderBot():
     '''
     AutoTrader Bot.
+    ---------------
     
     Attributes
     ----------
@@ -62,6 +63,8 @@ class AutoTraderBot():
         self.data_file          = autotrader_attributes.data_file
         self.optimise_mode      = autotrader_attributes.optimise_mode
         self.include_broker     = autotrader_attributes.include_broker
+        self.check_data_alignment = autotrader_attributes.check_data_alignment
+        self.allow_dancing_bears = autotrader_attributes.allow_dancing_bears
         
         self.instrument         = instrument
         self.broker             = broker
@@ -70,7 +73,7 @@ class AutoTraderBot():
         interval                = strategy_config["INTERVAL"]
         period                  = strategy_config["PERIOD"]
         risk_pc                 = strategy_config["RISK_PC"]
-        sizing                  = strategy_config["SIZING"]
+        sizing                  = strategy_config["SIZING"] if 'SIZING' in strategy_config else 0
         params                  = strategy_config["PARAMETERS"]
         
         strategy_params                 = params
@@ -100,15 +103,19 @@ class AutoTraderBot():
                                                              global_config,
                                                              self.feed)
         
-        self.get_data           = autodata.GetData(broker_config)
-        data, quote_data        = self.retrieve_data(instrument, self.feed)
+        self.get_data           = autodata.GetData(broker_config, self.allow_dancing_bears)
+        data, quote_data        = self._retrieve_data(instrument, self.feed)
         
         # instantiate strategy
-        my_strat = strategy(params, data, instrument)
+        # my_strat = strategy(params, data, instrument)
         
         if self.include_broker:
-                my_strat.broker = self.broker
-                my_strat.broker_utils = self.broker_utils
+            # my_strat.broker = self.broker
+            # my_strat.broker_utils = self.broker_utils
+            my_strat = strategy(params, data, instrument, self.broker, self.broker_utils)
+        else:
+            my_strat = strategy(params, data, instrument)
+            
                 
         self.strategy           = my_strat
         self.data               = data
@@ -120,10 +127,25 @@ class AutoTraderBot():
         if int(self.verbosity) > 0:
                 print("AutoTraderBot assigned to analyse {}".format(instrument),
                       "on {} timeframe using {}.".format(self.strategy_params['granularity'],
-                                                         self.strategy.name))
+                                                         strategy_config['NAME']))
     
+    def _update_strategy_data(self):
+        '''
+        Method to update strategy with latest data. Called by the bot manager.
+        '''
+        
+        print("Updating strategy with latest data.")
+        
+        # TODO - add option to get dancing bears in autodata
+        
+        # Download new data
+        new_data, _ = self._retrieve_data(self.instrument, self.feed)
+        
+        # Update strategy with new data
+        self.strategy.initialise_strategy(new_data)
+        
     
-    def retrieve_data(self, instrument, feed):
+    def _retrieve_data(self, instrument, feed):
         '''
         Retrieves price data from AutoData.
         '''
@@ -235,14 +257,14 @@ class AutoTraderBot():
             data = getattr(self.get_data, feed.lower())(instrument,
                                                          granularity = interval,
                                                          count=period)
-            
-            data = self.verify_data_alignment(data, instrument, feed, period, 
-                                              price_data_path)
+            if self.check_data_alignment:
+                data = self._verify_data_alignment(data, instrument, feed, period, 
+                                                  price_data_path)
         
             return data, None
 
 
-    def verify_data_alignment(self, data, instrument, feed, period, price_data_path):
+    def _verify_data_alignment(self, data, instrument, feed, period, price_data_path):
         '''
         Verifies data time-alignment based on current time and last
         candle in data.
@@ -303,7 +325,7 @@ class AutoTraderBot():
         return data
     
     
-    def update(self, i):
+    def _update(self, i):
         '''
         Update strategy with latest data and generate latest signal.
         '''
@@ -325,7 +347,7 @@ class AutoTraderBot():
             order_signal_dict = signal_dict[order].copy()
             
             if order_signal_dict["direction"] != 0:
-                self.process_signal(order_signal_dict, i, self.data, 
+                self._process_signal(order_signal_dict, i, self.data, 
                                     self.quote_data, self.instrument)
         
         if int(self.verbosity) > 1:
@@ -399,7 +421,7 @@ class AutoTraderBot():
                                                 self.email_params['host_email'])
                     
     
-    def update_backtest(self, i):
+    def _update_backtest(self, i):
         '''
         Updates virtual broker with latest price data.
         '''
@@ -407,7 +429,7 @@ class AutoTraderBot():
         self.broker.update_positions(candle, self.instrument)
     
     
-    def process_signal(self, order_signal_dict, i, data, quote_data, 
+    def _process_signal(self, order_signal_dict, i, data, quote_data, 
                        instrument):
         '''
             Process order_signal_dict and send orders to broker.
@@ -506,7 +528,7 @@ class AutoTraderBot():
             
             
 
-    def create_backtest_summary(self, NAV, margin):
+    def create_backtest_summary(self, balance, NAV, margin):
         '''
         Constructs backtest summary dictionary for further processing.
         '''
@@ -529,6 +551,7 @@ class AutoTraderBot():
         backtest_dict = {}
         backtest_dict['data']           = self.data
         backtest_dict['NAV']            = NAV
+        backtest_dict['balance']        = balance
         backtest_dict['margin']         = margin
         backtest_dict['trade_summary']  = trade_summary
         backtest_dict['indicators']     = self.strategy.indicators if hasattr(self.strategy, 'indicators') else None
@@ -539,7 +562,7 @@ class AutoTraderBot():
         
         self.backtest_summary = backtest_dict
     
-    def get_iteration_range(self):
+    def _get_iteration_range(self):
         '''
         Checks mode of operation and returns data iteration range. For backtesting,
         the entire dataset is iterated over. For livetrading, only the latest candle
