@@ -28,6 +28,7 @@ from autotrader.lib import instrument_list, environment_manager, printout
 from autotrader.lib.read_yaml import read_yaml
 from autotrader import autoplot
 from autotrader.autobot import AutoTraderBot
+from autotrader.lib.bot_manager import ManageBot
 
 
 class AutoTrader():
@@ -36,7 +37,7 @@ class AutoTrader():
     
     Kieran Mackle
     
-    Version 0.3.0
+    Version 0.4.0
     
 
     Attributes
@@ -76,6 +77,11 @@ class AutoTrader():
         self.show_plot      = False
         self.plot_validation_balance = True
         
+        # Livetrade Parameters
+        self.detach_bot     = False         # TODO - make this a strategy config option
+        self.check_data_alignment = True
+        self.allow_dancing_bears = False
+        
         # self.config         = None
         self.broker         = None
         self.broker_utils   = None
@@ -141,9 +147,12 @@ class AutoTrader():
                 self.notify = 0
         
         if self.optimise_mode:
-            self.run_optimise()
+            if self.backtest_mode:
+                self._run_optimise()
+            else:
+                print("Please set backtest parameters to run optimisation.")
         else:
-            self.main()
+            self._main()
     
     def usage(self):
         '''
@@ -160,7 +169,7 @@ class AutoTrader():
         '''
         printout.option_help(option)
         
-    def main(self):
+    def _main(self):
         '''
         Main run file of autotrader.py. This method is called internally 
         from the "run" method.
@@ -199,7 +208,7 @@ class AutoTrader():
         # else:
         #     self.watchlist  = config["WATCHLIST"]
         
-        self.assign_broker(broker_config)
+        self._assign_broker(broker_config)
         self.configure_emailing(global_config)
         
         if self.backtest_mode:
@@ -228,11 +237,20 @@ class AutoTrader():
         '''    Assign strategy to bot for each instrument in watchlist     '''
         ''' -------------------------------------------------------------- '''
         for strategy in self.strategies:
-            for instrument in self.strategies[strategy]['WATCHLIST']:
-                bot = AutoTraderBot(instrument, self.strategies[strategy],
-                                    self.broker, self)
-                self.bots_deployed.append(bot)
-            
+                for instrument in self.strategies[strategy]['WATCHLIST']:
+                    bot = AutoTraderBot(instrument, self.strategies[strategy],
+                                            self.broker, self)
+                    
+                    if self.detach_bot is True and self.backtest_mode is False:
+                        # Send bot to bot manager to monitor stream
+                        print("Passing bot to bot manager...")
+                        bot_name_string = "{}_{}_{}".format(strategy.replace(' ',''),
+                                                            self.strategies[strategy]['INTERVAL'],
+                                                            instrument)
+                        ManageBot(bot, self.home_dir, bot_name_string)
+                    else:
+                        self.bots_deployed.append(bot)
+                    
         
         ''' -------------------------------------------------------------- '''
         '''                  Analyse price data using strategy             '''
@@ -242,21 +260,22 @@ class AutoTrader():
         
         # TODO - add check that data ranges are consistent across bots
         # For now, assume correct and use first bot.
-        start_range, end_range = self.bots_deployed[0].get_iteration_range()
-        for i in range(start_range, end_range):
-            
-            # Update each bot with latest data to generate signal
-            for bot in self.bots_deployed:
-                bot.update(i)
+        if not self.detach_bot:
+            start_range, end_range = self.bots_deployed[0]._get_iteration_range()
+            for i in range(start_range, end_range):
                 
-                # If backtesting, update virtual broker with latest data
-                if self.backtest_mode:
-                    bot.update_backtest(i)
-            
-            if self.backtest_mode is True:
-                NAV.append(self.broker.NAV)
-                balance.append(self.broker.portfolio_balance)
-                margin.append(self.broker.margin_available)
+                # Update each bot with latest data to generate signal
+                for bot in self.bots_deployed:
+                    bot._update(i)
+                    
+                    # If backtesting, update virtual broker with latest data
+                    if self.backtest_mode:
+                        bot._update_backtest(i)
+                
+                if self.backtest_mode is True:
+                    NAV.append(self.broker.NAV)
+                    balance.append(self.broker.portfolio_balance)
+                    margin.append(self.broker.margin_available)
         
         ''' -------------------------------------------------------------- '''
         '''                     Backtest Post-Processing                   '''
@@ -265,7 +284,7 @@ class AutoTrader():
         if self.backtest_mode is True:
             # Create backtest summary for each bot 
             for bot in self.bots_deployed:
-                bot.create_backtest_summary(NAV, margin)            
+                bot.create_backtest_summary(balance, NAV, margin)            
             
             if int(self.verbosity) > 0:
                 print("\nBacktest complete.")
@@ -296,8 +315,9 @@ class AutoTrader():
             if self.show_plot:
                 if len(self.bots_deployed) == 1:
                     if self.validation_file is None:
-                        # ap.plot_backtest(bot.backtest_summary)
-                        self.plot_backtest(bot=self.bots_deployed[0])
+                        if len(self.bots_deployed[0].backtest_summary['trade_summary']) > 0:
+                            self.plot_backtest(bot=self.bots_deployed[0])
+                        
                     else:
                         self.plot_backtest(bot=self.bots_deployed[0], 
                                            validation_file=self.validation_file)
@@ -306,25 +326,25 @@ class AutoTrader():
                     # Backtest run with multiple bots
                     cpl_dict = {}
                     for bot in self.bots_deployed:
+                        
                         profit_df = pd.merge(bot.data, 
                                  bot.backtest_summary['trade_summary']['Profit'], 
                                  left_index=True, right_index=True).Profit.cumsum()
                         cpl_dict[bot.instrument] = profit_df
                     
-                    ap = autoplot.AutoPlot()
-                    ap.data = bot.data
-                    ap.plot_multibot_backtest(self.multibot_backtest_results, 
+                    ap = autoplot.AutoPlot(bot.data)
+                    ap._plot_multibot_backtest(self.multibot_backtest_results, 
                                               NAV,
                                               cpl_dict)
 
-    def clear_strategies(self):
+    def _clear_strategies(self):
         '''
         Removes all strategies saved in autotrader instance.
         '''
         
         self.strategies = {}
     
-    def clear_bots(self):
+    def _clear_bots(self):
         '''
         Removes all deployed bots in autotrader instance.
         '''
@@ -352,6 +372,14 @@ class AutoTrader():
             new_strategy = strategy_dict
         
         name = new_strategy['NAME']
+        
+        if name in self.strategies:
+            print("Warning: duplicate strategy name deteced. Please check " + \
+                  "the NAME field of your strategy configuration file and " + \
+                  "make sure it is not the same as other strategies being " + \
+                  "run from this instance.")
+            print("Conflicting name:", name)
+        
         self.strategies[name] = new_strategy
     
     
@@ -435,14 +463,13 @@ class AutoTrader():
                 
                 validation_file (str): filepath of backtest validation file.
         '''
-        ap = autoplot.AutoPlot()
-        ap.data = bot.data
+        ap = autoplot.AutoPlot(bot.data)
         profit_df = pd.merge(bot.data, 
                              bot.backtest_summary['trade_summary']['Profit'], 
                              left_index=True, right_index=True).Profit.cumsum()
         
         if validation_file is None:
-            ap.plot_backtest(bot.backtest_summary, cumulative_PL=profit_df)
+            ap.plot(bot.backtest_summary, cumulative_PL=profit_df)
             
         else:
             ap.plot_validation_balance = self.plot_validation_balance # User option flag
@@ -477,14 +504,23 @@ class AutoTrader():
             backtest_results = self.analyse_backtest(bot.backtest_summary)
             
             instruments.append(bot.instrument)
-            win_rate.append(backtest_results['all_trades']['win_rate'])
             no_trades.append(backtest_results['no_trades'])
-            avg_win.append(backtest_results['all_trades']['avg_win'])
-            max_win.append(backtest_results['all_trades']['max_win'])
-            avg_loss.append(backtest_results['all_trades']['avg_loss'])
-            max_loss.append(backtest_results['all_trades']['max_loss'])
-            no_long.append(backtest_results['long_trades']['no_trades'])
-            no_short.append(backtest_results['short_trades']['no_trades'])
+            if backtest_results['no_trades'] > 0:
+                win_rate.append(backtest_results['all_trades']['win_rate'])
+                avg_win.append(backtest_results['all_trades']['avg_win'])
+                max_win.append(backtest_results['all_trades']['max_win'])
+                avg_loss.append(backtest_results['all_trades']['avg_loss'])
+                max_loss.append(backtest_results['all_trades']['max_loss'])
+                no_long.append(backtest_results['long_trades']['no_trades'])
+                no_short.append(backtest_results['short_trades']['no_trades'])
+            else:
+                win_rate.append(np.nan)
+                avg_win.append(np.nan)
+                max_win.append(np.nan)
+                avg_loss.append(np.nan)
+                max_loss.append(np.nan)
+                no_long.append(np.nan)
+                no_short.append(np.nan)
             
         
         multibot_backtest_results = pd.DataFrame(data={'win_rate': win_rate,
@@ -606,6 +642,7 @@ class AutoTrader():
         print("         MultiBot Backtest Results")
         print("---------------------------------------------------")
         print("Instruments traded: ", backtest_results.index.values)
+        print("Final NAV:           ${}".format(round(self.broker.NAV, 2)))
         print("Total no trades:    ", backtest_results.no_trades.sum())
         print("Short trades:       ", backtest_results.no_short.sum(),
               "({}%)".format(round(100*backtest_results.no_short.sum()/backtest_results.no_trades.sum(),2)))
@@ -620,28 +657,11 @@ class AutoTrader():
         print("")
         
     
-    def granularity_to_seconds(self, granularity):
-        '''Converts the interval to time in seconds'''
-        letter = granularity[0]
+    def _assign_broker(self, broker_config):
+        '''
+        Configures and assigns appropriate broker for trading.
+        '''
         
-        if len(granularity) > 1:
-            number = float(granularity[1:])
-        else:
-            number = 1
-        
-        conversions = {'S': 1,
-                       'M': 60,
-                       'H': 60*60,
-                       'D': 60*60*24
-                       }
-        
-        my_int = conversions[letter] * number
-        
-        return my_int
-
-
-    
-    def assign_broker(self, broker_config):
         if self.backtest_mode is True:
                 utils_module    = importlib.import_module('autotrader.brokers.virtual.utils')
                 
@@ -654,7 +674,7 @@ class AutoTrader():
                 commission      = self.backtest_commission
                 base_currency   = self.backtest_base_currency
                 
-                broker.add_funds(initial_deposit)
+                broker.make_deposit(initial_deposit)
                 broker.fee      = spread
                 broker.leverage = leverage
                 broker.commission = commission
@@ -817,16 +837,17 @@ class AutoTrader():
     def print_backtest_results(self, backtest_results):
         # params      = self.strategy_params
         no_trades   = backtest_results['no_trades']
-        win_rate    = backtest_results['all_trades']['win_rate']
-        profit_abs  = backtest_results['all_trades']['profit_abs']
-        profit_pc   = backtest_results['all_trades']['profit_pc']
-        MDD         = backtest_results['all_trades']['MDD']
-        max_win     = backtest_results['all_trades']['max_win']
-        avg_win     = backtest_results['all_trades']['avg_win']
-        max_loss    = backtest_results['all_trades']['max_loss']
-        avg_loss    = backtest_results['all_trades']['avg_loss']
-        longest_win_streak = backtest_results['all_trades']['win_streak']
-        longest_lose_streak = backtest_results['all_trades']['lose_streak']
+        if no_trades > 0:
+            win_rate    = backtest_results['all_trades']['win_rate']
+            profit_abs  = backtest_results['all_trades']['profit_abs']
+            profit_pc   = backtest_results['all_trades']['profit_pc']
+            MDD         = backtest_results['all_trades']['MDD']
+            max_win     = backtest_results['all_trades']['max_win']
+            avg_win     = backtest_results['all_trades']['avg_win']
+            max_loss    = backtest_results['all_trades']['max_loss']
+            avg_loss    = backtest_results['all_trades']['avg_loss']
+            longest_win_streak = backtest_results['all_trades']['win_streak']
+            longest_lose_streak = backtest_results['all_trades']['lose_streak']
         
         print("\n-------------------------------------------")
         print("            Backtest Results")
@@ -915,11 +936,15 @@ class AutoTrader():
         Optimisation configuration.
         
             Parameters: 
-                opt_params (list): 
+                opt_params (list): the parameters to be optimised, as they 
+                are named in the strategy configuration file.
                 
-                bounds (list of tuples):
+                bounds (list of tuples): the bounds on each of the 
+                parameters to be optimised, specified as a tuple of the form
+                (lower, upper) for each parameter.
                 
-                Ns (int):
+                Ns (int): the number of points along each dimension of the 
+                optimisation grid.
                 
         '''
         
@@ -936,7 +961,7 @@ class AutoTrader():
         self.Ns = Ns
         
         
-    def run_optimise(self):
+    def _run_optimise(self):
         '''
         Runs optimisation of strategy parameters.
         '''
@@ -969,7 +994,7 @@ class AutoTrader():
         '''                             Run Optimiser                       '''
         ''' --------------------------------------------------------------- '''
         start = timeit.default_timer()
-        result = brute(func         = self.optimisation_helper_function, 
+        result = brute(func         = self._optimisation_helper_function, 
                        ranges       = self.bounds, 
                        args         = my_args, 
                        Ns           = self.Ns,
@@ -1013,7 +1038,7 @@ class AutoTrader():
         self.verbosity = verbosity
     
     
-    def optimisation_helper_function(self, params, config_dict, opt_params, verbosity):
+    def _optimisation_helper_function(self, params, config_dict, opt_params, verbosity):
         '''
         Helper function for optimising strategy parameters in AutoTrader.
         This function will parse the ordered params into the config dict.
@@ -1032,10 +1057,10 @@ class AutoTrader():
         ''' ------------------------------------------------------------------ '''
         '''           Run AutoTrader and evaluate objective function           '''
         ''' ------------------------------------------------------------------ '''
-        self.clear_strategies()
-        self.clear_bots()
+        self._clear_strategies()
+        self._clear_bots()
         self.add_strategy(strategy_dict = config_dict)
-        self.main()
+        self._main()
         
         bot = self.bots_deployed[0]
         
